/*
 * $Id: RangeFinderVPI.java,v 1.1.1.1 2004/12/14 00:25:39 norman Exp $
 *
 * Copyright (C) 2004 by Brockmann Consult (info@brockmann-consult.de)
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation. This program is distributed in the hope it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package com.bc.beam.visat.rangeFinder;

import org.esa.beam.framework.ui.command.Command;
import org.esa.beam.framework.ui.command.CommandEvent;
import org.esa.beam.framework.ui.command.CommandStateListener;
import org.esa.beam.framework.ui.command.ToolCommand;
import org.esa.beam.framework.ui.product.ProductSceneView;
import org.esa.beam.visat.VisatApp;
import org.esa.beam.visat.VisatPlugIn;

import javax.swing.*;

/**
 * Installs a plug-in which provides a tool that can be used to measure lengths
 * within an image view.
 * <p>
 * It is a bit more complex example, because it uses VISAT's tool framework
 * in order to provide interactive 2-point dragging for defining the length
 * to measure.
 *
 * @author Sabine Embacher
 */
public class RangeFinderVPI implements VisatPlugIn {

    private ToolCommand _rangeFinderCmd;

    /**
     * Called by VISAT after the plug-in instance has been registered
     * in VISAT's plug-in manager.
     *
     * @param visatApp a reference to the VISAT application instance.
     */
    public void initPlugIn(final VisatApp visatApp) {

        CommandStateListener listener = new CommandStateListener() {
            public void updateState(CommandEvent event) {
                final Command command = event.getCommand();
                if (command != null) {
                    final ProductSceneView view = visatApp.getSelectedProductSceneView();
                    command.setEnabled(view != null && view.getProduct().getGeoCoding() != null);
                }
            }
        };

        _rangeFinderCmd = visatApp.createToolCommand("rangeFinder", listener, new RangeFinderTool());
        _rangeFinderCmd.setText("Range Finder...");
        _rangeFinderCmd.setLargeIcon(loadImageIcon("RangeFinder24.gif"));
        _rangeFinderCmd.setShortDescription("Range finder tool");
        _rangeFinderCmd.setLongDescription("Determine the distance between two points");

        ToolbarHelper.addToToolbar(visatApp,
                                   _rangeFinderCmd.createToolBarButton(),
                                   VisatApp.CMD_ID_SELECT_TOOL);
    }


    /**
     * Tells a plug-in to update its component tree (if any) since the
     * Java look-and-feel has changed.
     *
     * <p>If a plug-in uses top-level containers such as dialogs or frames,
     * implementors of this method should invoke <code>SwingUtilities.updateComponentTreeUI()</code>
     * on such containers.
     */
    public void updateComponentTreeUI() {
    }


    /**
     * Load the toolbar icon resource.
     * @param resourcename the icon name
     * @return  the toolbar icon
     */
    static ImageIcon loadImageIcon(final String resourcename) {
        final java.net.URL resource = RangeFinderVPI.class.getResource(resourcename);
        return resource != null ? new ImageIcon(resource) : null;
    }
}
