/*
 * $Id: ToolbarHelper.java,v 1.1.1.1 2004/12/14 00:25:39 norman Exp $
 *
 * Copyright (C) 2004 by Brockmann Consult (info@brockmann-consult.de)
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation. This program is distributed in the hope it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package com.bc.beam.visat.rangeFinder;

import org.esa.beam.visat.VisatApp;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ContainerAdapter;
import java.awt.event.ContainerEvent;
import java.awt.event.ContainerListener;

/**
 * This a utility class which is used to a component to
 * VISAT's toolbar when the toolbar is added.
 * In BEAM 2.3 the VisatApp class will provide direct access
 * to it's toolbar. Until then, we need this helper class to
 * insert a component into the toolbar
 *
 * @author Norman Fomferra
 */
public class ToolbarHelper extends ContainerAdapter {

    /**
     * Adds a component to VISAT's tool bar.
     * @param visatApp the VISAT application
     * @param component the new component to add
     * @param insertAfter  the name (e.g. command ID) of the toolbar component after which
     *                     the new component shall be placed
     */
    public static void addToToolbar(final VisatApp visatApp, JComponent component, String insertAfter) {
        component.addMouseListener(visatApp.getMouseOverActionHandler());
        ContainerListener containerListener = new ToolbarAdder(component, insertAfter);
        visatApp.getMainFrame().getContentPane().addContainerListener(containerListener);
    }

    private static class ToolbarAdder extends ContainerAdapter {

        private JComponent _component;
        private String _insertAfter;

        public ToolbarAdder(JComponent component, String insertAfter) {
            _component = component;
            _insertAfter = insertAfter;
        }

        /**
         * Invoked when a component has been added to the toolbar.
         */
        public void componentAdded(ContainerEvent e) {
            final Component child = e.getChild();
            if (child instanceof JToolBar) {
                JToolBar toolBar = (JToolBar) child;
                if (toolBar.getComponentIndex(_component) == -1) {
                    int index = findToolBarButtonIndex(toolBar);
                    toolBar.add(_component, index);
                }
            }
        }

        private int findToolBarButtonIndex(final JToolBar toolBar) {
            int index = toolBar.getComponentCount();
            if (_insertAfter != null) {
                final Component[] components = toolBar.getComponents();
                for (int i = 0; i < components.length; i++) {
                    if (_insertAfter.equals(components[i].getName())) {
                        index = i + 1;
                        break;
                    }
                }
            }
            return index;
        }

    }
}
